@@ -22,16 +22,16 @@
  *    Phone: (608)262-0438         1210 West Dayton Street
  *      FAX: (608)262-9777         Madison, WI   53706
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: mgv/dsc.c,v 1.13 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: mgv/dsc.c,v 1.17 $")
 
-#include	<stdio.h>
-#include	<string.h>
-#include	<ctype.h>
-#include	<stdlib.h>
-#include	<sys/types.h>
+#include <stdio.h>
+#include <string.h>
+#include <ctype.h>
+#include <stdlib.h>
+#include <sys/types.h>
 
-#include	<mine/dsc.h>
+#include <mine/dsc.h>
 
 #ifndef BUFSIZ
 #	define BUFSIZ 1024
@@ -373,6 +373,8 @@ gettextline(char *line)
  *      %%Title: <textline>
  *      %%DocumentMedia: <text> <real> <real> <real> <text> <text>
  *      %%DocumentPaperSizes: <text>
+ *	%%For: <text>
+ *	%%Creator: <text>
  *      %%EndComments
  *
  *      Note: Either the 3.0 or 2.0 syntax for %%Pages is accepted.
@@ -486,8 +488,15 @@ dsc_scan(FILE *file)
 
 	/*
 	 * Header comments
+	 *
+	 * We can get away with only looking for "%!" here.
+	 * We should be looking for the DSC standard "%!PS-Adobe-"
+	 * but some programs can't write proper PostScript (even
+	 * FrameMaker is guilty of this sometimes).  If the document
+	 * isn't DSC compliant, then the DSC* we're building will have
+	 * "n_pages" equal to zero and we'll return NULL at the end.
 	 */
-	if(!iscomment(line,"%!PS-Adobe-")
+	if(!iscomment(line, "%!")
 	|| (dsc = calloc(1, sizeof(DSC))) == NULL)
 		return NULL;
 	dsc->type = DSC_PS;
@@ -509,6 +518,10 @@ dsc_scan(FILE *file)
 	    break;
 	} else if (line[1] != '%') {
 	    /* Do nothing */
+	} else if (dsc->forwho == NULL && iscomment(line+2, "For:")) {
+	    dsc->forwho = gettextline(line+length("%%For:"));
+	} else if (dsc->creator == NULL && iscomment(line+2, "Creator:")) {
+	    dsc->creator = gettextline(line+length("%%Creator:"));
 	} else if (dsc->title == NULL && iscomment(line+2, "Title:")) {
 	    dsc->title = gettextline(line+length("%%Title:"));
 	} else if (dsc->date == NULL && iscomment(line+2, "CreationDate:")) {
@@ -1219,6 +1232,15 @@ continuepage:
 		}
 	}
 
+	/*
+	 * Weird (or non-DSC) document.  Keep in mind that
+	 * zero pages is the norm with EPS files (I remembered
+	 * this the hard way).
+	 */
+	if(dsc->n_pages == 0
+	&& dsc->type    != DSC_EPS)
+		dsc = dsc_free(dsc);
+
 	return dsc;
 }
 
@@ -1242,6 +1264,8 @@ dsc_free(DSC *dsc)
 	free((void *)dsc->date);
 	free((void *)dsc->pages);
 	free((void *)dsc->media);
+	free((void *)dsc->forwho);
+	free((void *)dsc->creator);
 	free((void *)dsc);
 
 	return NULL;
