@@ -19,17 +19,17 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: mgv/events.c,v 1.10 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: mgv/events.c,v 1.12 $")
 
-#include	<assert.h>
-#include	<Xm/RowColumn.h>
+#include <assert.h>
+#include <Xm/RowColumn.h>
 
-#include	<wlib/wlib.h>
-#include	<mine/mgv.h>
-#include	<mine/events.h>
+#include <wlib/wlib.h>
+#include <mine/mgv.h>
+#include <mine/events.h>
 
 void
 mgv_events(Widget w, XtPointer closure, XEvent *ev, Boolean *cont)
