@@ -19,31 +19,33 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: mgv/mgv.c,v 1.147 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: mgv/mgv.c,v 1.159 $")
 
-#include	<assert.h>
-#include	<ctype.h>
-#include	<string.h>
-#include	<stdlib.h>
-#include	<unistd.h>
-#include	<errno.h>
-#include	<Xm/List.h>
-#include	<Xm/ToggleB.h>
-#include	<Xm/ScrolledW.h>
-#include	<Xm/ScrollBar.h>
+#include <assert.h>
+#include <ctype.h>
+#include <string.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <errno.h>
+#include <Xm/List.h>
+#include <Xm/ToggleB.h>
+#include <Xm/ScrolledW.h>
+#include <Xm/ScrollBar.h>
 
-#include	<wlib/wlib.h>
-#include	<mine/mgv.h>
-#include	<mine/app.h>
-#include	<mine/unmangle.h>
-#include	<mine/log.h>
-#include	<mine/sens.h>
-#include	<mine/strings.h>
-#include	<mine/zoom.h>
-#include	<mine/auto.h>
+#include <wlib/wlib.h>
+#include <mine/mgv.h>
+#include <mine/app.h>
+#include <mine/unmangle.h>
+#include <mine/log.h>
+#include <mine/sens.h>
+#include <mine/strings.h>
+#include <mine/zoom.h>
+#include <mine/auto.h>
+#include <mine/util.h>
+#include <mine/page_control.h>
 
 static void
 title(MGV *m)
@@ -68,17 +70,21 @@ title(MGV *m)
  * would get reset but the window wouldn't actually scroll, the scrollbars
  * are always managed these days but this works so I'm leaving it alone).
  */
-static char *sbs[] = {"*VertScrollBar", "*HorScrollBar"};
 static void
-resetsbs(Widget swin)
+resetsbs(Widget swin, int which)
 {
 	Widget 	w;
 	WL_SBV	v;
-	int	i;
 
-	for(i = 0; i < (int)(sizeof(sbs)/sizeof(sbs[0])); ++i) {
+	if(which & MgvRESETSCROLL_H) {
 		memset((void *)&v, '\0', sizeof(v));
-		w = wl_getsbvalues(swin, sbs[i], &v);
+		w = wl_getsbvalues(swin, "*HorScrollBar", &v);
+		v.value = v.min;
+		wl_setsbvalues(w, &v, True);
+	}
+	if(which & MgvRESETSCROLL_V) {
+		memset((void *)&v, '\0', sizeof(v));
+		w = wl_getsbvalues(swin, "*VertScrollBar", &v);
 		v.value = v.min;
 		wl_setsbvalues(w, &v, True);
 	}
@@ -91,7 +97,7 @@ resetsbs(Widget swin)
  * up.
  */
 void
-mgv_close(MGV *m, int kludge)
+mgv_close(MGV *m, int kludge, int reset_kludge)
 {
 	String	s;
 
@@ -99,9 +105,18 @@ mgv_close(MGV *m, int kludge)
 	 * Reset the widgetry.  If you don't reset the scrollbars here,
 	 * the scrolled window widget can get really confused (seems to
 	 * only happen when you've scrolled to the bottom with some files).
+	 *
+	 * However, if you try to reset the scrollbars while the scrolled
+	 * window is dying (generally this means you're closing the window)
+	 * _and_ the scrollbars are not in their home positions, then
+	 * some older versions of Motif (Motif 1.2.3 based on personal
+	 * experience and bug reports, 2.0.1 and 1.2.5 appear to deal with
+	 * this just fine but I have had problem reports with 1.2.5) will be
+	 * naughty and dump core.
 	 */
 	mgv_zoom_killall(m);
-	resetsbs(m->sw);
+	if(!reset_kludge)
+		resetsbs(m->sw, m->bits & MgvRESETSCROLL);
 	XmListDeleteAllItems(m->list);
 	if(m->orienttog != NULL && !kludge) {
 		XtVaSetValues(m->orienttog, XmNset, False, NULL);
@@ -142,6 +157,7 @@ mgv_close(MGV *m, int kludge)
 	m->fp       = NULL;
 	m->page     =
 	m->n_marked = 0;
+	m->pgstack  = mgv_pgstack_free(m->pgstack);
 	m->sens    &= ~(MgvSALL & ~MgvSLOG);
 	if(!kludge)
 		m->bits &= ~MgvFORCEDORIENT;
@@ -252,20 +268,19 @@ init(MGV *m)
  * Really open a file.  Hmm, this gettin' a little grotty me thinks.
  */
 static int
-openit(MGV *m)
+openit(MGV *m, int no_dsc)
 {
-	int		i, max;
-	char		buf[64];
-	XmString	xstr;
-	Widget		alias;
+	Widget	alias;
 
 	if(m->fp == NULL)
 		return 0;
 	rewind(m->fp);
 	mgv_zoom_killall(m);
 	XmListDeleteAllItems(m->list);
-	dsc_free(m->dsc);
-	if((m->dsc = dsc_scan(m->fp)) != NULL
+	m->dsc = dsc_free(m->dsc);
+
+	if(!no_dsc
+	&& (m->dsc = dsc_scan(m->fp)) != NULL
 	&& m->dsc->type    != DSC_EPS
 	&& m->dsc->n_pages == 0) {
 		dsc_free(m->dsc);
@@ -316,14 +331,7 @@ openit(MGV *m)
 	/*
 	 * then set sensible values for the UI widgetry
 	 */
-	max = (m->dsc == NULL) ? 0 : m->dsc->n_pages;
-	for(i = 1; i <= max; ++i) {
-		mgv_label(m, i - 1, buf);
-		xstr = XmStringCreateLtoR(buf, "UNMARKED");
-		XmListAddItemUnselected(m->list, xstr, i);
-		XmStringFree(xstr);
-	}
-
+	mgv_list_update(m, -1);
 	XtVaSetValues(wl_find1(m->main, "*nameFrame*name"),
 		XtVaTypedArg,	XmNlabelString,
 				XmRString, m->title,
@@ -370,6 +378,37 @@ openit(MGV *m)
 	return 0;
 }
 
+/*
+ * Open and scan a file pointer (this currently assumes that "fp" is
+ * really stdin).
+ */
+int
+mgv_open_fp(MGV *m, FILE *fp)
+{
+	int	try_dsc;
+
+	if(mgv_appres(m->main)->copy_stdin) {
+		m->fp   = mgv_tcopy(m, &m->realfile, fp);
+		m->file = XtNewString("stdin");
+		try_dsc = TRUE;
+	}
+	else {
+		m->fp       = fp;
+		m->realfile = XtNewString("-");
+		m->file     = XtNewString("stdin");
+		try_dsc     = FALSE;
+	}
+	m->pgstack  = mgv_pgstack_alloc(m);
+	openit(m, !try_dsc);
+	if(m->dsc != NULL)
+		mgv_pgstack_prefill(m->pgstack, m->dsc->n_pages);
+	title(m);
+	m->sens |= MgvSOPEN;
+	mgv_sens(m->main, m->sens);
+
+	return 0;
+}
+
 /*
  * open and scan a file
  */
@@ -389,7 +428,7 @@ mgv_open(MGV *m, char *file)
 	realfile = XtNewString(myfile);
 	if((myfile = mgv_unmangle(m, myfile)) == NULL
 	|| (fp     = fopen(myfile, "r"))      == NULL) {
-		status = EPERM;
+		status = errno;
 		goto Hell;
 	}
 
@@ -400,14 +439,17 @@ mgv_open(MGV *m, char *file)
 	 * the orientation switches will not stick).
 	 */
 	if(m->file != NULL)
-		mgv_close(m, file == NULL && (m->bits & MgvFORCEDORIENT));
+		mgv_close(m,file == NULL && (m->bits & MgvFORCEDORIENT), FALSE);
 
 	m->fp       = fp;
 	m->realfile = myfile;
 	m->file     = realfile;
-	openit(m);
+	m->pgstack  = mgv_pgstack_alloc(m);
+	openit(m, FALSE);
+	if(m->dsc != NULL)
+		mgv_pgstack_prefill(m->pgstack, m->dsc->n_pages);
 	title(m);
-	m->sens |= MgvSOPEN;
+	m->sens |= MgvSOPEN | MgvSCANREOPEN;
 	mgv_sens(m->main, m->sens);
 
 	return 0;
@@ -462,8 +504,7 @@ mgv_show(MGV *m, int page)
 	}
 	m->page = page;
 
-	if(m->bits & MgvRESETSCROLL)
-		resetsbs(m->sw);
+	resetsbs(m->sw, m->bits & MgvRESETSCROLL);
 
 	/*
 	 * new page orientation
@@ -552,7 +593,7 @@ mgv_orient(MGV *m, GvPageOrientation orient, int force)
 	 * window will get all confused
 	 */
 	if(m->orient != orient)
-		resetsbs(m->sw);
+		resetsbs(m->sw, MgvRESETSCROLL);
 	if(force)
 		m->bits |= MgvFORCEDORIENT;
 	else
@@ -601,54 +642,23 @@ mgv_magnify(MGV *m, int mag)
 }
 
 void
-mgv_mark(MGV *m, int page, int mark)
+mgv_mark(MGV *m, int page, int mark, int update)
 {
-	Widget		p;
-	XmString	xstr;
-	char		buf[64];
-
 	if(m == NULL
 	|| m->dsc == NULL
 	|| m->dsc->pages == NULL
 	|| m->dsc->pages[page].mark == mark)
 		return;
 	m->dsc->pages[page].mark = mark;
-	mgv_label(m, page, buf);
-	xstr = XmStringCreateLtoR(buf, (mark ? "MARKED" : "UNMARKED"));
-	XmListReplaceItemsPos(m->list, &xstr, 1, page + 1);
-	XmStringFree(xstr);
-	if(page == m->page)
-		XmListSelectPos(m->list, page + 1, False);
 
-	/*
-	 * This bit of chicanery is a work around for a bug in 
-	 * the Motif 1.2 list widget.  The item height in a list
-	 * is the maximum of the vertical font extents for all
-	 * fonts currently in use; thus, the item height will change
-	 * whenever you add a new item with a larger font or remove
-	 * the last item in a larger font.  The Motif 1.2 list will
-	 * not properly redraw itself in these cases--it will only
-	 * redraw the individual items which leaves little messes
-	 * in the spaces between the items; the Motif 2.0 list
-	 * appears to deal with this correctly though.
-	 *
-	 * So, whenever the list item height will change, we 
-	 * do a quick one-two punch on the list to force a
-	 * redraw.
-	 */
-	p = XtParent(m->list);
-	if(XtIsManaged(p)
-	&& ((mark && m->n_marked == 0) || (!mark && m->n_marked == 1))) {
-		XtUnmanageChild(p);
-		XtVaSetValues(p, XmNrightAttachment, XmATTACH_FORM, NULL);
-		XtManageChild(p);
-	}
 	m->n_marked += (mark ? 1 : -1);
 	if(m->n_marked > 0)
 		m->sens |= MgvSMARKED;
 	else
 		m->sens &= ~MgvSMARKED;
-	mgv_sens(m->main, m->sens);
+
+	if(update)
+		mgv_list_update(m, page + 1);
 }
 
 /*
@@ -919,6 +929,7 @@ mgv_free(MGV *m)
 	 * main window
 	 */
 	assert(m->dsc == NULL);
+	m->pgstack = mgv_pgstack_free(m->pgstack);
 	free((void *)m);
 
 	return NULL;
@@ -977,7 +988,6 @@ mgv_ok(MGV *m, int zoom)
 	DIEIF(m->clip			== NULL);
 	DIEIF(m->list			== NULL);
 	DIEIF(m->tracker		== NULL);
-	DIEIF(m->temp_dir		== NULL);
 	DIEIF(m->n_marked		 < 0);
 	DIEIF(m->smoothness		<= 0);
 	DIEIF(m->autosizer		== NULL);
