@@ -19,42 +19,41 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: mgv/mgv_create.c,v 1.138 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: mgv/mgv_create.c,v 1.150 $")
 
-#include	<assert.h>
-#include	<stdlib.h>
-#include	<errno.h>
-#include	<signal.h>
-#include	<unistd.h>
-#include	<X11/Intrinsic.h>
-#include	<X11/Xmu/Editres.h>
-#include	<Xm/ToggleB.h>
-#include	<Xm/AtomMgr.h>
-#include	<Xm/Protocols.h>
+#include <assert.h>
+#include <stdlib.h>
+#include <errno.h>
+#include <signal.h>
+#include <unistd.h>
+#include <X11/Intrinsic.h>
+#include <Xm/ToggleB.h>
+#include <Xm/AtomMgr.h>
+#include <Xm/Protocols.h>
 
-#include	<wlib/wlib.h>
-#include	<wlib/icons.h>
-#include	<mine/mgv.h>
-#include	<mine/app.h>
-#include	<mine/file.h>
-#include	<mine/events.h>
-#include	<mine/help.h>
-#include	<mine/log.h>
-#include	<mine/magstep.h>
-#include	<mine/media.h>
-#include	<mine/options.h>
-#include	<mine/orientation.h>
-#include	<mine/page.h>
-#include	<mine/mark.h>
-#include	<mine/print.h>
-#include	<mine/sens.h>
-#include	<mine/track.h>
-#include	<mine/window.h>
-#include	<mine/zoom.h>
-#include	<mine/auto.h>
+#include <wlib/wlib.h>
+#include <wlib/icons.h>
+#include <mine/mgv.h>
+#include <mine/app.h>
+#include <mine/file.h>
+#include <mine/events.h>
+#include <mine/help.h>
+#include <mine/log.h>
+#include <mine/magstep.h>
+#include <mine/media.h>
+#include <mine/options.h>
+#include <mine/orientation.h>
+#include <mine/page.h>
+#include <mine/mark.h>
+#include <mine/print.h>
+#include <mine/sens.h>
+#include <mine/track.h>
+#include <mine/window.h>
+#include <mine/zoom.h>
+#include <mine/auto.h>
 
 #if defined(ABS)
 #	undef ABS
@@ -72,6 +71,7 @@ static WLW menu_file[] = {
 	{"reopen",		wlPushBG,	0, NULL},
 	{"save",		wlPushBG,	0, NULL},
 	{"print",		wlPushBG,	0, NULL},
+	{"info",		wlPushBG,	0, NULL},
 	{"sep",			wlSeparatorG,	0, NULL},
 	{"close",		wlPushBG,	0, NULL},
 	{"exit",		wlPushBG,	0, NULL},
@@ -103,7 +103,6 @@ static WLW menu_page[] = {
 static WLW menu_mark[] = {
 	{"mark",		wlPushBG,	0, NULL},
 	{"markAll",		wlPushBG,	0, NULL},
-	{"unmark",		wlPushBG,	0, NULL},
 	{"unmarkAll",		wlPushBG,	0, NULL},
 	{"even",		wlPushBG,	0, NULL},
 	{"odd",			wlPushBG,	0, NULL},
@@ -270,8 +269,24 @@ static WLW main_widget[] = {
 	{NULL}
 };
 
+/*
+ * Almost the same as menu_window[].
+ */
+static WLW menu_popup_kids[] = {
+	{"back",		wlPushBG,	0, NULL},
+	{"forward",		wlPushBG,	0, NULL},
+	{"sep2",		wlSeparatorG,	0, NULL},
+	{"hideLog",		wlToggleBG,	0, NULL},
+	{"hideList",		wlToggleBG,	0, NULL},
+	{"hideStatus",		wlToggleBG,	0, NULL},
+	{"hideMenu",		wlToggleBG,	0, NULL},
+	{"sep2",		wlSeparatorG,	0, NULL},
+	{"closeZoom",		wlPushBG,	0, NULL},
+	{NULL}
+};
+
 static WLW menu_popup[] = {
-	{"popup",		wlPopupMenu,	0, menu_window},
+	{"popup",		wlPopupMenu,	0, menu_popup_kids},
 	{NULL}
 };
 
@@ -284,6 +299,8 @@ static WLC cb[] = {
 		0, NULL, mgv_file_save},
 	{"*menuBar*file_pd*print", XmNactivateCallback,
 		0, NULL, mgv_print},
+	{"*menuBar*file_pd*info", XmNactivateCallback,
+		0, NULL, mgv_file_info},
 	{"*menuBar*file_pd*close", XmNactivateCallback,
 		0, NULL, mgv_file_close},
 	{"*menuBar*file_pd*exit", XmNactivateCallback,
@@ -315,8 +332,6 @@ static WLC cb[] = {
 		0, NULL, mgv_mark_mark},
 	{"*menuBar*mark_pd*markAll", XmNactivateCallback,
 		0, NULL, mgv_mark_markall},
-	{"*menuBar*mark_pd*unmark", XmNactivateCallback,
-		0, NULL, mgv_mark_mark},
 	{"*menuBar*mark_pd*unmarkAll", XmNactivateCallback,
 		0, NULL, mgv_mark_markall},
 	{"*menuBar*mark_pd*even", XmNactivateCallback,
@@ -448,6 +463,10 @@ static WLC cb[] = {
 	{"*menuBar*window_pd*closeZoom", XmNactivateCallback,
 		0, NULL, mgv_window_zoom},
 
+	{"*popup*back", XmNactivateCallback,
+		0, NULL, mgv_page_backforward},
+	{"*popup*forward", XmNactivateCallback,
+		0, NULL, mgv_page_backforward},
 	{"*popup*hideLog", XmNvalueChangedCallback,
 		0, NULL, mgv_window_log},
 	{"*popup*hideLog", XmNvalueChangedCallback,
@@ -545,14 +564,12 @@ mgv_create(Widget parent, char *file)
 	m->zoom_linewidth   = r->reticule_width;
 	m->default_media    = r->default_page_media;
 	m->parent           = NULL;
-	m->temp_dir         = r->temp_dir;
-	m->decompress       = r->decompress;
 	m->labels           = r->show_labels;
 	m->pgnums           = r->show_pgnums;
-	m->smoothness       = ABS(r->smoothness);
-	m->magic_resistance = ABS(r->magic_resistance);
+	m->smoothness       = r->smoothness;
+	m->magic_resistance = r->magic_resistance;
 	m->scrollfactor     = r->scroll_percentage / 1000.0;
-	if(r->reset_scroll)	m->bits |= MgvRESETSCROLL;
+	m->bits            |= r->reset_scroll;
 	if(r->antialias_eps)	m->bits |= MgvALIASEPS;
 	if(r->smart_sizing)	m->bits |= MgvSMARTSIZE;
 	if(r->magic_scroll)	m->bits |= MgvMAGICSCROLL, toggle |= TOG_MAGIC;
@@ -562,18 +579,6 @@ mgv_create(Widget parent, char *file)
 	if(r->hide_menu)	toggle |= TOG_MENU;
 	if(r->hide_status)	toggle |= TOG_STAT;
 
-	/*
-	 *,,,the various resource sanity checks should probably
-	 *,,,be in app.c
-	 */
-
-	/*
-	 * They may have been silly enough to say "smoothness: 0"
-	 * users are funny that way.
-	 */
-	if(m->smoothness == 0)
-		m->smoothness = 1;
-
 	if(!m->labels && !m->pgnums)
 		toggle |= TOG_PGLIST;
 
@@ -599,7 +604,6 @@ mgv_create(Widget parent, char *file)
 		NULL);
 	XtVaGetValues(m->sw,   XmNclipWindow,     &m->clip,          NULL);
 	XtVaSetValues(menubar, XmNmenuHelpWidget, help,              NULL);
-	XtVaSetValues(m->main, XmNinitialFocus,   XtParent(m->list), NULL);
 	XtAddCallback(parent, XmNdestroyCallback, mgv_app_close, (XtPointer)m);
 
 	/*
@@ -644,21 +648,16 @@ mgv_create(Widget parent, char *file)
 	deletewin = XmInternAtom(XtDisplay(parent), "WM_DELETE_WINDOW", False);
 	XmAddWMProtocolCallback(parent, deletewin, mgv_file_close,(XtPointer)m);
 
-	/*
-	 * I really hate casting functions but the Editres.h header
-	 * doesn't have a prototype (sigh)
-	 */
-	XtAddEventHandler(parent, (EventMask)0, True,
-				(XtEventHandler)_XEditResCheckMessages, NULL);
-
 	/*
 	 * open file
 	 */
 	status = 0;
 	if(file != NULL)
 		status = mgv_open(m, file);
+	else if(!isatty(fileno(stdin)))
+		status = mgv_open_fp(m, stdin);
 	else
-		mgv_close(m, FALSE);
+		mgv_close(m, FALSE, FALSE);
 
 	mgv_ui_magnify(m, r->magstep);
 
@@ -701,7 +700,7 @@ mgv_create(Widget parent, char *file)
 		break;
 	}
 	XmToggleButtonSetState(wl_find1(m->main, sizer), True, False);
-	XmToggleButtonSetState(wl_find1(m->main,"*options_pd*smartSizing"),
+	XmToggleButtonSetState(wl_find1(m->main, "*options_pd*smartSizing"),
 				(m->bits & MgvSMARTSIZE) ? True : False, False);
 
 	XtAddEventHandler(m->main, ButtonPressMask, False, mgv_events,
@@ -709,7 +708,7 @@ mgv_create(Widget parent, char *file)
 
 	if(status != 0) {
 		wl_warn(m->main, "%s: %s", file, strerror(status));
-		mgv_close(m, FALSE);
+		mgv_close(m, FALSE, FALSE);
 	}
 
 	return m;
