@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_AUTO_H
 #define	MGV_AUTO_H
-MU_HID(auto_h, "$Mu: mgv/mine/auto.h,v 1.3 $")
+MU_HID(auto_h, "$Mu: mgv/mine/auto.h,v 1.4 $")
 
 CDECLS_BEGIN
 extern	void	mgv_auto_height(MGV *);
