@@ -19,14 +19,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_FILE_H
 #define	MGV_FILE_H
-MU_HID(file_h, "$Mu: mgv/mine/file.h,v 1.24 $")
+MU_HID(file_h, "$Mu: mgv/mine/file.h,v 1.26 $")
 
 CDECLS_BEGIN
 extern	void	mgv_file_close(Widget, XtPointer, XtPointer);
+extern	void	mgv_file_info(Widget, XtPointer, XtPointer);
 extern	void	mgv_file_open(Widget, XtPointer, XtPointer);
 extern	void	mgv_file_reopen(Widget, XtPointer, XtPointer);
 extern	void	mgv_file_save(Widget, XtPointer, XtPointer);
