@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_HELP_H
 #define	MGV_HELP_H
-MU_HID(help_h, "$Mu: mgv/mine/help.h,v 1.17 $")
+MU_HID(help_h, "$Mu: mgv/mine/help.h,v 1.18 $")
 
 CDECLS_BEGIN
 extern	void	mgv_help_about(Widget, XtPointer, XtPointer);
