@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_LOG_H
 #define	MGV_LOG_H
-MU_HID(log_h, "$Mu: mgv/mine/log.h,v 1.20 $")
+MU_HID(log_h, "$Mu: mgv/mine/log.h,v 1.21 $")
 
 CDECLS_BEGIN
 extern	void	mgv_log_hide(MGV *mgv, int hide, int toggle);
