@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_MAGSTEP_H
 #define	MGV_MAGSTEP_H
-MU_HID(magstep_h, "$Mu: mgv/mine/magstep.h,v 1.21 $")
+MU_HID(magstep_h, "$Mu: mgv/mine/magstep.h,v 1.22 $")
 
 CDECLS_BEGIN
 extern	int	mgv_ui_magnify(MGV *, int);
