@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_MARK_H
 #define	MGV_MARK_H
-MU_HID(mark_h, "$Mu: mgv/mine/mark.h,v 1.4 $")
+MU_HID(mark_h, "$Mu: mgv/mine/mark.h,v 1.5 $")
 
 CDECLS_BEGIN
 extern	void	mgv_action_mark(Widget, XEvent *, String *, Cardinal *);
