@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_OPTIONS_H
 #define	MGV_OPTIONS_H
-MU_HID(options_h, "$Mu: mgv/mine/options.h,v 1.11 $")
+MU_HID(options_h, "$Mu: mgv/mine/options.h,v 1.12 $")
 
 CDECLS_BEGIN
 extern	void	mgv_options_antialias(Widget, XtPointer, XtPointer);
