@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_PAGE_H
 #define	MGV_PAGE_H
-MU_HID(page_h, "$Mu: mgv/mine/page.h,v 1.31 $")
+MU_HID(page_h, "$Mu: mgv/mine/page.h,v 1.33 $")
 
 CDECLS_BEGIN
 extern	void	mgv_action_scroll(Widget, XEvent *, String *, Cardinal *);
@@ -31,6 +31,7 @@ extern	void	mgv_page_center(Widget, XtPointer, XtPointer);
 extern	void	mgv_page_goto(Widget, XtPointer, XtPointer);
 extern	void	mgv_page_labels(Widget, XtPointer, XtPointer);
 extern	void	mgv_page_nextprev(Widget, XtPointer, XtPointer);
+extern	void	mgv_page_backforward(Widget, XtPointer, XtPointer);
 extern	void	mgv_page_redisplay(Widget, XtPointer, XtPointer);
 extern	void	mgv_page_size(Widget, XtPointer, XtPointer);
 CDECLS_END
