@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_PRINT_H
 #define	MGV_PRINT_H
-MU_HID(print_h, "$Mu: mgv/mine/print.h,v 1.16 $")
+MU_HID(print_h, "$Mu: mgv/mine/print.h,v 1.17 $")
 
 CDECLS_BEGIN
 extern	void	mgv_print(Widget, XtPointer, XtPointer);
