@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_STRINGS_H
 #define	MGV_STRINGS_H
-MU_HID(strings_h, "$Mu: mgv/mine/strings.h,v 1.13 $")
+MU_HID(strings_h, "$Mu: mgv/mine/strings.h,v 1.16 $")
 
 /*
  * the MgvS<x> entry in this list corresponds to the MgvNstring<x> resource
@@ -45,6 +45,12 @@ enum {
 	MgvSnoFile,
 	MgvSnoPrintCommand,
 	MgvSpageFinished,
+	MgvSunknownSwitch,
+	MgvSPS,
+	MgvSEPS,
+	MgvSPDF,
+	MgvSunknownType,
+	MgvSunknownMedia,
 	MgvSunknown
 };
 CDECLS_BEGIN
