@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_TRACK_H
 #define	MGV_TRACK_H
-MU_HID(track_h, "$Mu: mgv/mine/track.h,v 1.15 $")
+MU_HID(track_h, "$Mu: mgv/mine/track.h,v 1.16 $")
 
 CDECLS_BEGIN
 extern	void	mgv_track(Widget, XtPointer, XtPointer);
