@@ -19,14 +19,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_UNMANGLE_H
 #define	MGV_UNMANGLE_H
-MU_HID(unmangle_h, "$Mu: mgv/mine/unmangle.h,v 1.9 $")
+MU_HID(unmangle_h, "$Mu: mgv/mine/unmangle.h,v 1.11 $")
 
 CDECLS_BEGIN
 extern	char	*mgv_unmangle(MGV *, char *);
+extern	FILE	*mgv_tcopy(MGV *, char **name, FILE *src);
 CDECLS_END
 
 #endif
