@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	MGV_ZOOM_H
 #define	MGV_ZOOM_H
-MU_HID(zoom_h, "$Mu: mgv/mine/zoom.h,v 1.21 $")
+MU_HID(zoom_h, "$Mu: mgv/mine/zoom.h,v 1.22 $")
 
 CDECLS_BEGIN
 extern	void	mgv_action_zoom(Widget, XEvent *, String *, Cardinal *);
