@@ -19,14 +19,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #include	<wlib/rcs.h>
-MU_ID("$Mu: wlib/dismiss.c,v 1.11 $")
+MU_ID("$Mu: wlib/dismiss.c,v 1.13 $")
 
-#include	<Xm/DialogS.h>
+#include <Xm/DialogS.h>
 
-#include	<wlib/wlib.h>
+#include <wlib/wlib.h>
 
 /*
  * Unmanage the dialog box which holds "w".
