@@ -20,14 +20,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: wlib/find.c,v 1.21 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: wlib/find.c,v 1.23 $")
 
-#include	<stdarg.h>
+#include <stdarg.h>
 
-#include	<wlib/wlib.h>
+#include <wlib/wlib.h>
 
 void
 wl_find(Widget parent, ...)
