@@ -20,14 +20,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: wlib/findup.c,v 1.6 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: wlib/findup.c,v 1.8 $")
 
-#include	<stdarg.h>
+#include <string.h>
 
-#include	<wlib/wlib.h>
+#include <wlib/wlib.h>
 
 Widget
 wl_findup(Widget w, char *name)
