@@ -19,18 +19,18 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: wlib/free_pixmap.c,v 1.1 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: wlib/free_pixmap.c,v 1.3 $")
 
-#include	<X11/Xlib.h>
-#include	<wlib/sanity.h>
+#include <X11/Xlib.h>
+#include <wlib/sanity.h>
 
-void
+Pixmap
 wl_free_pixmap(Display *dpy, Pixmap p)
 {
-	if(dpy == NULL || p == None)
-		return;
-	XFreePixmap(dpy, p);
+	if(dpy != NULL && p != None)
+		XFreePixmap(dpy, p);
+	return None;
 }
