@@ -19,12 +19,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: wlib/popup_dialog.c,v 1.2 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: wlib/popup_dialog.c,v 1.4 $")
 
-#include	<wlib/wlib.h>
+#include <wlib/wlib.h>
 
 /*
  * A simple function for doing all the standard things to bring
