@@ -20,15 +20,16 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: wlib/togglesync.c,v 1.3 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: wlib/togglesync.c,v 1.5 $")
 
-#include	<assert.h>
-#include	<Xm/ToggleB.h>
-#include	<wlib/typesanity.h>
-#include	<wlib/wlib.h>
+#include <assert.h>
+#include <Xm/ToggleB.h>
+
+#include <wlib/typesanity.h>
+#include <wlib/wlib.h>
 
 /*
  * The "closure" should be a widget path from the top level widget
