@@ -19,12 +19,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
-#include	<wlib/rcs.h>
-MU_ID("$Mu: wlib/top.c,v 1.8 $")
+#include <wlib/rcs.h>
+MU_ID("$Mu: wlib/top.c,v 1.10 $")
 
-#include	<wlib/wlib.h>
+#include <wlib/wlib.h>
 
 Widget
 wl_top(Widget w)
