@@ -19,12 +19,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  **
- * $Mu: wlib/wlib/WlAppShell-xrm.h,v 1.4 $
+ * $Mu: wlib/wlib/WlAppShell-xrm.h,v 1.7 $
  */
 	{"-depth",	"*wlDepth",		XrmoptionSepArg, NULL},
+	{"-editres",	"*wlUseEditRes",	XrmoptionNoArg,  "True"},
 	{"-install",	"*wlUsePrivateColormap",XrmoptionNoArg,	"True"},
+	{"-noeditres",	"*wlUseEditRes",	XrmoptionNoArg,  "False"},
 	{"-noinstall",	"*wlUsePrivateColormap",XrmoptionNoArg,	"True"},
 	{"-noprivatecm","*wlUsePrivateColormap",XrmoptionNoArg,  "False"},
 	{"-privatecm",	"*wlUsePrivateColormap",XrmoptionNoArg,  "True"},
