@@ -19,19 +19,19 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  *
  * This widget is loosely based an the AppPlusS widget by John L. Cwikla
  * <cwikla@wri.com>.
  */
 #ifndef WLIB_WLAPPSHELL_H
 #define WLIB_WLAPPSHELL_H
-MU_HID(wlib_wlappshell_h, "$Mu: wlib/wlib/WlAppShell.h,v 1.2 $")
+MU_HID(wlib_wlappshell_h, "$Mu: wlib/wlib/WlAppShell.h,v 1.4 $")
 
-#include	<X11/Shell.h>
-#include	<wlib/strdefs.h>
+#include <X11/Shell.h>
+#include <wlib/strdefs.h>
 
-extern	WidgetClass	wlAppShellWidgetClass;
+extern WidgetClass wlAppShellWidgetClass;
 
 #define XwlIsWlAppShell(a) (XtIsSubclass(a, wlAppShellWidgetClass))
 
