@@ -19,11 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	WLIB_SANITY_H
 #define	WLIB_SANITY_H
-MU_HID(wlib_sanity_h, "$Mu: wlib/wlib/sanity.h,v 1.1 $")
+MU_HID(wlib_sanity_h, "$Mu: wlib/wlib/sanity.h,v 1.3 $")
 
 CDECLS_BEGIN
 /*
@@ -31,8 +31,9 @@ CDECLS_BEGIN
  * I got sick of all the silly "if this isn't dead, kill it" code, if
  * something is already dead, then killing it again should be very
  * easy so why should I have to check for life-signs all the time?
+ * For convenience, this function always returns "None".
  */
-extern	void	wl_free_pixmap(Display *, Pixmap);
+extern	Pixmap	wl_free_pixmap(Display *, Pixmap);
 CDECLS_END
 
 #endif
