@@ -19,12 +19,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  */
 #ifndef	WLIB_TYPESANITY_H
 #define	WLIB_TYPESANITY_H
-MU_HID(wlib_typesanity_h, "$Mu: wlib/wlib/typesanity.h,v 1.8 $")
+MU_HID(wlib_typesanity_h, "$Mu: wlib/wlib/typesanity.h,v 1.10 $")
 
+/*
+ * I'm sorry but these names are just too damn much!
+ */
 typedef	XmToggleButtonCallbackStruct		XmTBS;
 typedef	XmFileSelectionBoxCallbackStruct	XmFSS;
 typedef	XmListCallbackStruct			XmLSS;
