@@ -19,15 +19,18 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *   Authors:	Matthew D. Francey
- *		Eric A. Howe (mu@echo-on.net)
+ *		Eric A. Howe (mu@trends.net)
  **
- * $Mu: wlib/wlib/xrmoptions.h,v 1.8 $
+ * $Mu: wlib/wlib/xrmoptions.h,v 1.10 $
  */
 	{"-browser",	"*helpBrowser",		XrmoptionSepArg, NULL},
 	{"-helpport",	"*helpCCIPort",		XrmoptionSepArg, NULL},
 	{"-helptype",	"*helpType",		XrmoptionSepArg, NULL},
 	{"-prefix",	"*helpPrefix",		XrmoptionSepArg, NULL},
 
+	{"-noicon",     "*wlInstallIcon",	XrmoptionNoArg,  "False"},
+	{"-installicon","*wlInstallIcon",	XrmoptionNoArg,  "True"},
+
 	{"-coloricon",	"*wlUseColorIcon",	XrmoptionNoArg,  "True"},
 	{"-monoicon",	"*wlUseColorIcon",	XrmoptionNoArg,  "False"},
 	{"-nocoloricon","*wlUseColorIcon",	XrmoptionNoArg,  "False"},
